%
%
%
%
%
function [RAW_CHANGE,EOFobs_CHANGE] = GET_IQRchangeMAP_EOFobs_2041to2060_nEOFs(VARname,PERIOD,nEOF)

YY=1901:2099;

EOFon=zeros(5,1);
EOFon(1:nEOF)=1;

disp(EOFon)

%
%   Load EOF indices from the MPI-GE ensmeble
%

load(['Vars/NAOeofPROJ_MPIGE_' PERIOD '_from1901.mat'])




%
%   Load raw temperature and precipitation data from the MPI-GE ensmeble
%

if strcmp(VARname,'PR') & strcmp(PERIOD,'DJF')

    [VAR_MPIGEhist,VAR_MPIGErcp,MODEL,lon,lat] = GET_PR_MPIGE_hist_rcp45;
    HISTlength=104;

    [PCsMPIGE] = GET_nEOFsPROJ_MPIGE_DJF_from1901(5);

elseif strcmp(VARname,'PR') & strcmp(PERIOD,'JJA')

    [VAR_MPIGEhist,VAR_MPIGErcp,MODEL,lon,lat] = GET_PR_MPIGE_hist_rcp45_JJA;
    HISTlength=105;

    [PCsMPIGE] = GET_nEOFsPROJ_MPIGE_JJA_from1901(5);

elseif strcmp(VARname,'TAS') & strcmp(PERIOD,'DJF')

    [VAR_MPIGEhist,VAR_MPIGErcp,MODEL,lon,lat] = GET_TAS_MPIGE_hist_rcp45;
    HISTlength=104;

    [PCsMPIGE] = GET_nEOFsPROJ_MPIGE_DJF_from1901(5);

elseif strcmp(VARname,'TAS') & strcmp(PERIOD,'JJA')

    [VAR_MPIGEhist,VAR_MPIGErcp,MODEL,lon,lat] = GET_TAS_MPIGE_hist_rcp45_JJA;
    HISTlength=105;

    [PCsMPIGE] = GET_nEOFsPROJ_MPIGE_JJA_from1901(5);

end

VARall=cat(3,VAR_MPIGEhist,VAR_MPIGErcp);
VARall=VARall(:,:,41:end,:);

clear VAR_MPIGEhist VAR_MPIGErcp

VARanom=zeros(size(VARall));

for ee=1:size(VARall,4)
    for tt=1:size(VARall,4)
        VARanom(:,:,tt,ee)=squeeze(VARall(:,:,tt,ee)) - squeeze(mean(VARall(:,:,1:HISTlength,ee),3));
    end
end

%=== TEST CASE ===
VARanom=VARall;


RAW_CHANGE=[];

for ee=1:size(VARanom,4)

    CHANGEtemp=squeeze(mean(VARanom(:,:,YY>=2041 & YY<=2060,ee),3) - mean(VARanom(:,:,YY>=1995 & YY<=2014,ee),3));

    RAW_CHANGE=cat(3,RAW_CHANGE,CHANGEtemp);

end

MEDIAN_RAW_CHANGE=prctile(RAW_CHANGE,50,3);

WRITE_NETCDF_VAR(['MEDIAN_RAW_' VARname '_' PERIOD '.nc'],MEDIAN_RAW_CHANGE);



%===== REMOVE EOF INFLUENCE USING INTERANNUAL REGRESSIONS ======

VARanom_woEOF=zeros(size(VARanom));

EOF1regALL=[];
EOF2regALL=[];
EOF3regALL=[];
EOF4regALL=[];
EOF5regALL=[];

EOF1corrALL=[];
EOF2corrALL=[];
EOF3corrALL=[];
EOF4corrALL=[];
EOF5corrALL=[];

for ee=1:size(VARanom,4)

    [EOF1reg,EOF1corr] = GET_REGRESScorr_3D_FAST(squeeze(PCsMPIGE(1,1:HISTlength,ee))',VARanom(:,:,1:HISTlength,ee));
    [EOF2reg,EOF2corr] = GET_REGRESScorr_3D_FAST(squeeze(PCsMPIGE(2,1:HISTlength,ee))',VARanom(:,:,1:HISTlength,ee));
    [EOF3reg,EOF3corr] = GET_REGRESScorr_3D_FAST(squeeze(PCsMPIGE(3,1:HISTlength,ee))',VARanom(:,:,1:HISTlength,ee));
    [EOF4reg,EOF4corr] = GET_REGRESScorr_3D_FAST(squeeze(PCsMPIGE(4,1:HISTlength,ee))',VARanom(:,:,1:HISTlength,ee));
    [EOF5reg,EOF5corr] = GET_REGRESScorr_3D_FAST(squeeze(PCsMPIGE(5,1:HISTlength,ee))',VARanom(:,:,1:HISTlength,ee));

    EOF1regALL=cat(3,EOF1regALL,EOF1reg);
    EOF2regALL=cat(3,EOF2regALL,EOF2reg);
    EOF3regALL=cat(3,EOF3regALL,EOF3reg);
    EOF4regALL=cat(3,EOF4regALL,EOF4reg);
    EOF5regALL=cat(3,EOF5regALL,EOF5reg);

    EOF1corrALL=cat(3,EOF1corrALL,EOF1corr);
    EOF2corrALL=cat(3,EOF2corrALL,EOF2corr);
    EOF3corrALL=cat(3,EOF3corrALL,EOF3corr);
    EOF4corrALL=cat(3,EOF4corrALL,EOF4corr);
    EOF5corrALL=cat(3,EOF5corrALL,EOF5corr);

    for tt=1:size(VARanom,3)
        VARanom_woEOF(:,:,tt,ee)=VARanom(:,:,tt,ee) - EOFon(1)*EOF1regALL(:,:,ee)*PCsMPIGE(1,tt,ee) - EOFon(2)*EOF2regALL(:,:,ee)*PCsMPIGE(2,tt,ee) ...
         - EOFon(3)*EOF3regALL(:,:,ee)*PCsMPIGE(3,tt,ee) - EOFon(4)*EOF4regALL(:,:,ee)*PCsMPIGE(4,tt,ee) - EOFon(5)*EOF5regALL(:,:,ee)*PCsMPIGE(5,tt,ee);
    end
    disp(ee)
end

RAW_STD=[];

VARanom_woEOFbar=mean(VARanom_woEOF,4);
VARanom_woEOFanom=zeros(size(VARanom_woEOF));
for ee=1:size(VARanom,4)
    VARanom_woEOFanom(:,:,:,ee)=squeeze(VARanom_woEOF(:,:,:,ee))-VARanom_woEOFbar;

    RAW_STD=cat(3,RAW_STD,std(squeeze(VARanom(:,:,1:HISTlength,ee)),0,3));
end






%===== ADD EOF INFLUENCE USING OBS EOF VARIABILITY ======

if strcmp(PERIOD,'DJF')

    [PCs_HadSLP] = GET_nEOFs_HadSLP2_DJF_1901to2005(5);

    [PCs_TREN] = GET_nEOFsPROJ_TRENBERTH_DJF_1901to2005(5);
    [PCs_20CR] = GET_nEOFsPROJ_20CR_DJF_1901to2005(5);
    [PCs_CERA] = GET_nEOFsPROJ_CERA20C_DJF_1901to2005(5);

elseif strcmp(PERIOD,'JJA')

    [PCs_HadSLP] = GET_nEOFs_HadSLP2_JJA_1901to2005(5);

    [PCs_TREN] = GET_nEOFsPROJ_TRENBERTH_JJA_1901to2005(5);
    [PCs_20CR] = GET_nEOFsPROJ_20CR_JJA_1901to2005(5);
    [PCs_CERA] = GET_nEOFsPROJ_CERA20C_JJA_1901to2005(5);

end



EOF1dummy=[];
EOF2dummy=[];
EOF3dummy=[];
EOF4dummy=[];
EOF5dummy=[];




%
%   Get the surrogate EOF indices using the function "GET_NAOindex_DUMMY.m"
%

NAO1=PCs_HadSLP(1,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO1,10000);
NAO1dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO2=PCs_HadSLP(2,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO2,10000);
NAO2dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO3=PCs_HadSLP(3,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO3,10000);
NAO3dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO4=PCs_HadSLP(4,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO4,10000);
NAO4dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO5=PCs_HadSLP(5,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO5,10000);
NAO5dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

EOF1dummy=cat(2,EOF1dummy,NAO1dummy);
EOF2dummy=cat(2,EOF2dummy,NAO2dummy);
EOF3dummy=cat(2,EOF3dummy,NAO3dummy);
EOF4dummy=cat(2,EOF4dummy,NAO4dummy);
EOF5dummy=cat(2,EOF5dummy,NAO5dummy);


%load(['Vars/NAOeofPROJ_20CR_' PERIOD '_1901to2005.mat']);
NAO1=PCs_TREN(1,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO1,10000);
NAO1dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO2=PCs_TREN(2,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO2,10000);
NAO2dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO3=PCs_TREN(3,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO3,10000);
NAO3dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO4=PCs_TREN(4,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO4,10000);
NAO4dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO5=PCs_TREN(5,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO5,10000);
NAO5dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

EOF1dummy=cat(2,EOF1dummy,NAO1dummy);
EOF2dummy=cat(2,EOF2dummy,NAO2dummy);
EOF3dummy=cat(2,EOF3dummy,NAO3dummy);
EOF4dummy=cat(2,EOF4dummy,NAO4dummy);
EOF5dummy=cat(2,EOF5dummy,NAO5dummy);


%load(['Vars/NAOeofPROJ_TRENBERTH_' PERIOD '_1901to2005.mat']);
NAO1=PCs_20CR(1,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO1,10000);
NAO1dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO2=PCs_20CR(2,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO2,10000);
NAO2dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO3=PCs_20CR(3,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO3,10000);
NAO3dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO4=PCs_20CR(4,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO4,10000);
NAO4dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO5=PCs_20CR(5,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO5,10000);
NAO5dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

EOF1dummy=cat(2,EOF1dummy,NAO1dummy);
EOF2dummy=cat(2,EOF2dummy,NAO2dummy);
EOF3dummy=cat(2,EOF3dummy,NAO3dummy);
EOF4dummy=cat(2,EOF4dummy,NAO4dummy);
EOF5dummy=cat(2,EOF5dummy,NAO5dummy);


%load(['Vars/NAOeofPROJ_CERA20C_' PERIOD '_1901to2005.mat']);
NAO1=PCs_CERA(1,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO1,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO1,10000);
NAO1dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO2=PCs_CERA(2,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO2,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO2,10000);
NAO2dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO3=PCs_CERA(3,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO3,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO3,10000);
NAO3dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO4=PCs_CERA(4,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO4,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO4,10000);
NAO4dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

NAO5=PCs_CERA(5,:);
[NAOdummyA] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyB] = GET_NAOindex_DUMMY(NAO5,10000);
[NAOdummyC] = GET_NAOindex_DUMMY(NAO5,10000);
NAO5dummy=cat(1,NAOdummyA,NAOdummyB,NAOdummyC);

EOF1dummy=cat(2,EOF1dummy,NAO1dummy);
EOF2dummy=cat(2,EOF2dummy,NAO2dummy);
EOF3dummy=cat(2,EOF3dummy,NAO3dummy);
EOF4dummy=cat(2,EOF4dummy,NAO4dummy);
EOF5dummy=cat(2,EOF5dummy,NAO5dummy);



EOFobs_CHANGE=[];

EOFobs_STD=[];

for ee=1:4:size(EOF1dummy,2)

    RANDstart=randi(100);
    RANDens=randi(size(VARanom_woEOF,4));

    EOF1temp=EOF1dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF2temp=EOF2dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF3temp=EOF3dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF4temp=EOF4dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF5temp=EOF5dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);

    EOF1temp=EOF1temp/std(EOF1temp(1:HISTlength));
    EOF2temp=EOF2temp/std(EOF2temp(1:HISTlength));
    EOF3temp=EOF3temp/std(EOF3temp(1:HISTlength));
    EOF4temp=EOF4temp/std(EOF4temp(1:HISTlength));
    EOF5temp=EOF5temp/std(EOF5temp(1:HISTlength));

    VARanomTEMP=zeros(size(VARanom,1),size(VARanom,2),size(VARanom,3));
    for tt=1:size(VARanom,3)
        VARanomTEMP(:,:,tt)=squeeze(VARanom_woEOF(:,:,tt,RANDens)) + EOFon(1)*EOF1regALL(:,:,RANDens)*EOF1temp(tt) + EOFon(2)*EOF2regALL(:,:,RANDens)*EOF2temp(tt) ...
        + EOFon(3)*EOF3regALL(:,:,RANDens)*EOF3temp(tt) + EOFon(4)*EOF4regALL(:,:,RANDens)*EOF4temp(tt) + EOFon(5)*EOF5regALL(:,:,RANDens)*EOF5temp(tt);
    end

    EOFobs_STD=cat(3,EOFobs_STD,std(squeeze(VARanomTEMP(:,:,1:HISTlength)),0,3));

    CHANGEtemp=mean(VARanomTEMP(:,:,YY>=2041 & YY<=2060),3) - mean(VARanomTEMP(:,:,YY>=1995 & YY<=2014),3);

    EOFobs_CHANGE=cat(3,EOFobs_CHANGE,single(CHANGEtemp));


    disp(ee)

end



%==== ADD EOF INFLUENCE USING OBS TELECONNECTION PATTERN ======


EOF1corrOBS=ncread(['Vars/TELEcorrOBS_EOF1_' VARname '_' PERIOD '.nc'],'VAR');
EOF2corrOBS=ncread(['Vars/TELEcorrOBS_EOF2_' VARname '_' PERIOD '.nc'],'VAR');
EOF3corrOBS=ncread(['Vars/TELEcorrOBS_EOF3_' VARname '_' PERIOD '.nc'],'VAR');
EOF4corrOBS=ncread(['Vars/TELEcorrOBS_EOF4_' VARname '_' PERIOD '.nc'],'VAR');
EOF5corrOBS=ncread(['Vars/TELEcorrOBS_EOF5_' VARname '_' PERIOD '.nc'],'VAR');



if strcmp(VARname,'PR')==1

EOF1corrOBS=flipdim(EOF1corrOBS,2);
EOF2corrOBS=flipdim(EOF2corrOBS,2);
EOF3corrOBS=flipdim(EOF3corrOBS,2);
EOF4corrOBS=flipdim(EOF4corrOBS,2);
EOF5corrOBS=flipdim(EOF5corrOBS,2);

end




EOFobsTELE_CHANGE=[];

EOFobsTELE_STD=[];


for ee=1:4:size(EOF1dummy,2)

    RANDstart=randi(100);
    RANDens=randi(size(VARanom_woEOF,4));

    EOF1temp=EOF1dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF2temp=EOF2dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF3temp=EOF3dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF4temp=EOF4dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF5temp=EOF5dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);

    EOF1temp=EOF1temp/std(EOF1temp(1:HISTlength));
    EOF2temp=EOF2temp/std(EOF2temp(1:HISTlength));
    EOF3temp=EOF3temp/std(EOF3temp(1:HISTlength));
    EOF4temp=EOF4temp/std(EOF4temp(1:HISTlength));
    EOF5temp=EOF5temp/std(EOF5temp(1:HISTlength));

    SIGMAraw=std(squeeze(VARanom(:,:,1:HISTlength,RANDens)),0,3);

    EOF1regOBStele=sign(EOF1corrOBS).*sqrt((EOF1corrOBS.^2).*(SIGMAraw.^2));
    EOF2regOBStele=sign(EOF1corrOBS).*sqrt((EOF2corrOBS.^2).*(SIGMAraw.^2));
    EOF3regOBStele=sign(EOF1corrOBS).*sqrt((EOF3corrOBS.^2).*(SIGMAraw.^2));
    EOF4regOBStele=sign(EOF1corrOBS).*sqrt((EOF4corrOBS.^2).*(SIGMAraw.^2));
    EOF5regOBStele=sign(EOF1corrOBS).*sqrt((EOF5corrOBS.^2).*(SIGMAraw.^2));

    SCALING_woEOF=zeros(size(SIGMAraw));


    VARanomTEMPeof=zeros(size(VARanom,1),size(VARanom,2),size(VARanom,3));
    for tt=1:size(VARanom,3)
        VARanomTEMPeof(:,:,tt) = VARanom_woEOFbar(:,:,tt) + EOFon(1)*EOF1regOBStele*EOF1temp(tt) + EOFon(2)*EOF2regOBStele*EOF2temp(tt) ...
        + EOFon(3)*EOF3regOBStele*EOF3temp(tt) + EOFon(4)*EOF4regOBStele*EOF4temp(tt) + EOFon(5)*EOF5regOBStele*EOF5temp(tt);
    end

    STD_VARanom=std(VARanom(:,:,1:HISTlength,RANDens),0,3);
    STD_VARanomTEMPeof=std(VARanomTEMPeof(:,:,1:HISTlength),0,3);

    STD_RESIDUAL=real(sqrt(STD_VARanom.^2 - STD_VARanomTEMPeof.^2));

    STD_VARanom_woEOFanom=std(VARanom_woEOFanom(:,:,1:HISTlength,RANDens),0,3);

    SCALING_woEOFanom=STD_RESIDUAL./STD_VARanom_woEOFanom;

    VARanomTEMP=zeros(size(VARanom,1),size(VARanom,2),size(VARanom,3));
    for tt=1:size(VARanom,3)
        VARanomTEMP(:,:,tt) = VARanomTEMPeof(:,:,tt) + SCALING_woEOFanom.*VARanom_woEOFanom(:,:,tt,RANDens);
    end

    EOFobsTELE_STD=cat(3,EOFobsTELE_STD,std(squeeze(VARanomTEMP(:,:,1:HISTlength)),0,3));

    CHANGEtemp=mean(VARanomTEMP(:,:,YY>=2041 & YY<=2060),3) - mean(VARanomTEMP(:,:,YY>=1995 & YY<=2014),3);

    EOFobsTELE_CHANGE=cat(3,EOFobsTELE_CHANGE,single(CHANGEtemp));


    disp(ee)

end





ok=22;





%===== ADD EOF INFLUENCE USING WHITE-NOISE VARIABILITY ======


EOFwhite_CHANGE=[];

EOF1dummy=randn(size(EOF1dummy));
EOF2dummy=randn(size(EOF2dummy));
EOF3dummy=randn(size(EOF3dummy));
EOF4dummy=randn(size(EOF4dummy));
EOF5dummy=randn(size(EOF5dummy));

for ee=1:4:size(EOF1dummy,2)

    RANDstart=randi(100);
    RANDens=randi(size(VARanom_woEOF,4));

    EOF1temp=EOF1dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF2temp=EOF2dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF3temp=EOF3dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF4temp=EOF4dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);
    EOF5temp=EOF5dummy(1+RANDstart:size(VARanom_woEOF,3)+RANDstart,ee);

    EOF1temp=EOF1temp/std(EOF1temp(1:HISTlength));
    EOF2temp=EOF2temp/std(EOF2temp(1:HISTlength));
    EOF3temp=EOF3temp/std(EOF3temp(1:HISTlength));
    EOF4temp=EOF4temp/std(EOF4temp(1:HISTlength));
    EOF5temp=EOF5temp/std(EOF5temp(1:HISTlength));

    VARanomTEMP=zeros(size(VARanom,1),size(VARanom,2),size(VARanom,3));
    for tt=1:size(VARanom,3)
        VARanomTEMP(:,:,tt)=squeeze(VARanom_woEOF(:,:,tt,RANDens)) + EOFon(1)*EOF1regALL(:,:,RANDens)*EOF1temp(tt) + EOFon(2)*EOF2regALL(:,:,RANDens)*EOF2temp(tt) ...
        + EOFon(3)*EOF3regALL(:,:,RANDens)*EOF3temp(tt) + EOFon(4)*EOF4regALL(:,:,RANDens)*EOF4temp(tt) + EOFon(5)*EOF5regALL(:,:,RANDens)*EOF5temp(tt);
    end


    CHANGEtemp=mean(VARanomTEMP(:,:,YY>=2041 & YY<=2060),3) - mean(VARanomTEMP(:,:,YY>=1995 & YY<=2014),3);

    EOFwhite_CHANGE=cat(3,EOFwhite_CHANGE,single(CHANGEtemp));


    disp(ee)

end




%===== CALCULATE SIGNIGICANCE LEVELS ====



[SIGNIFobs] = GET_IQR_SIGNIF_2D(RAW_CHANGE,EOFobs_CHANGE,10000);
[SIGNIFobsTELE] = GET_IQR_SIGNIF_2D(RAW_CHANGE,EOFobsTELE_CHANGE,10000);
[SIGNIFwhite] = GET_IQR_SIGNIF_2D(RAW_CHANGE,EOFwhite_CHANGE,10000);



%===== OUTPUT IQR LEVELS ====

MEDIAN_RAW_CHANGE=prctile(RAW_CHANGE,50,3);
WRITE_NETCDF_VAR(['MEDIAN_EOFobs_' VARname '_' PERIOD '.nc'],MEDIAN_RAW_CHANGE);

MEDIAN_EOFobs_CHANGE=prctile(EOFobs_CHANGE,50,3);
WRITE_NETCDF_VAR(['MEDIAN_EOFobs_' VARname '_' PERIOD '.nc'],MEDIAN_EOFobs_CHANGE);

MEDIAN_EOFobsTELE_CHANGE=prctile(EOFobsTELE_CHANGE,50,3);
WRITE_NETCDF_VAR(['MEDIAN_EOFobsTELE_' VARname '_' PERIOD '.nc'],MEDIAN_EOFobsTELE_CHANGE);

MEDIAN_EOFwhite_CHANGE=prctile(EOFwhite_CHANGE,50,3);
WRITE_NETCDF_VAR(['MEDIAN_EOFwhite_' VARname '_' PERIOD '.nc'],MEDIAN_EOFwhite_CHANGE);


IQR_RAW=prctile(RAW_CHANGE,75,3)-prctile(RAW_CHANGE,25,3);
IQR_EOFobs=prctile(EOFobs_CHANGE,75,3)-prctile(EOFobs_CHANGE,25,3);
IQR_EOFobsTELE=prctile(EOFobsTELE_CHANGE,75,3)-prctile(EOFobsTELE_CHANGE,25,3);
IQR_EOFwhite=prctile(EOFwhite_CHANGE,75,3)-prctile(EOFwhite_CHANGE,25,3);

IQR_EOFobsDIFF=IQR_EOFobs-IQR_RAW;
IQR_EOFobsTELEDIFF=IQR_EOFobsTELE-IQR_RAW;
IQR_EOFwhiteDIFF=IQR_EOFwhite-IQR_RAW;


%
% Save out netcdf files for figures
%

WRITE_NETCDF_VAR(['IQR_RAW_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_RAW);
WRITE_NETCDF_VAR(['IQR_EOFobs_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFobs);
WRITE_NETCDF_VAR(['IQR_EOFobsTELE_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFobsTELE);
WRITE_NETCDF_VAR(['IQR_EOFwhite_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFwhite);

WRITE_NETCDF_VAR(['IQR_EOFobsDIFF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFobsDIFF);
WRITE_NETCDF_VAR(['IQR_EOFobsSIGNIF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],SIGNIFobs);

WRITE_NETCDF_VAR(['IQR_EOFobsTELEDIFF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFobsTELEDIFF);
WRITE_NETCDF_VAR(['IQR_EOFobsTELESIGNIF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],SIGNIFobsTELE);

WRITE_NETCDF_VAR(['IQR_EOFwhiteDIFF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],IQR_EOFwhiteDIFF);
WRITE_NETCDF_VAR(['IQR_EOFwhiteSIGNIF_' VARname '_' PERIOD '_n' num2str(nEOF) '.nc'],SIGNIFwhite);


save('-v7.3',['Vars/EOFobsCHANGE_2041to2060_' VARname '_' PERIOD '_n' num2str(nEOF) '.mat'],'EOFobs_CHANGE','EOFobsTELE_CHANGE','EOFwhite_CHANGE','RAW_CHANGE')



ok=22;


end
